@@ -2,12 +2,13 @@ proc read_files {} {
 read_verilog -sv {sv_file.sv}
 source {tcl_file.tcl}
 read_verilog {vlog_file.v}
+read_verilog {vlog_with_define.v}
 read_verilog {vlog05_file.v}
 read_verilog -sv {another_sv_file.sv}
 }
 
 proc set_defines {} {
-set defines {{vlogdefine_bool True} {vlogdefine_int 42} {vlogdefine_str hello}}
+set defines {{vlogdefine_bool True} {vlogdefine_int 42} {vlogdefine_str hello} {CCGM 1}}
 
 foreach d ${defines} {
   set key [lindex $d 0]
