@@ -13,6 +13,4 @@ verilog_defaults -pop
 
 synth $top
 
-write_blif $name.blif
-write_json $name.json
-write_edif $name.edif
+write_json test_symbiflow_nextpnr_fpga_interchange_0.json
